# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from t2iapi.alert import alert_requests_pb2 as t2iapi_dot_alert_dot_alert__requests__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2


class AlertServiceStub(object):
    """
    Service to handle alert manipulations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetAlertConditionPresence = channel.unary_unary(
                '/t2iapi.alert.AlertService/SetAlertConditionPresence',
                request_serializer=t2iapi_dot_alert_dot_alert__requests__pb2.SetAlertConditionPresenceRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetAlertSignalPresence = channel.unary_unary(
                '/t2iapi.alert.AlertService/SetAlertSignalPresence',
                request_serializer=t2iapi_dot_alert_dot_alert__requests__pb2.SetAlertSignalPresenceRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetAudioPause = channel.unary_unary(
                '/t2iapi.alert.AlertService/SetAudioPause',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.CancelAudioPause = channel.unary_unary(
                '/t2iapi.alert.AlertService/CancelAudioPause',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.AlertConditionEscalation = channel.unary_unary(
                '/t2iapi.alert.AlertService/AlertConditionEscalation',
                request_serializer=t2iapi_dot_alert_dot_alert__requests__pb2.AlertConditionEscalationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetAlarmSignalInactivationState = channel.unary_unary(
                '/t2iapi.alert.AlertService/SetAlarmSignalInactivationState',
                request_serializer=t2iapi_dot_alert_dot_alert__requests__pb2.SetAlarmSignalInactivationStateRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetAlertSystemNotFunctional = channel.unary_unary(
                '/t2iapi.alert.AlertService/SetAlertSystemNotFunctional',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.InitiateAlarmOff = channel.unary_unary(
                '/t2iapi.alert.AlertService/InitiateAlarmOff',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )


class AlertServiceServicer(object):
    """
    Service to handle alert manipulations.
    """

    def SetAlertConditionPresence(self, request, context):
        """
        Set the AlertCondition/@Presence of the AlertCondition with the given handle to the given value.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAlertSignalPresence(self, request, context):
        """
        Set the AlertSignal/Presence for a given alert signal handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAudioPause(self, request, context):
        """
        Set device audio pause.
        Audio pause: if initiated, all SystemSignalActivation/State for all alarm systems of the device with
        SystemSignalActivation/Manifestation evaluating to 'Aud' shall be set to 'Psd'.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelAudioPause(self, request, context):
        """
        Cancel audio pause.
        Audio pause: suppresses the acoustic alarm signal of the device for all active alarms for a certain period of time.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AlertConditionEscalation(self, request, context):
        """
        Start/Stop an Escalation/Deescalation of the AlertConditionPriority for a given alert condition handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAlarmSignalInactivationState(self, request, context):
        """
        Change the state of the alarm signal inactivation state represented by the AlertCondition with the given
        handle as requested.

        Inactivation States can be for example:
        - Global Audio Pause, could have an condition with the text "Audio Pause"
        - "Pressures Off"
        - Cardiac By-Pass Mode
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAlertSystemNotFunctional(self, request, context):
        """
        Set the AlertSystem with the given handle to not functional.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitiateAlarmOff(self, request, context):
        """
        Initiate alarm off for the AlertCondition with the given handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlertServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetAlertConditionPresence': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAlertConditionPresence,
                    request_deserializer=t2iapi_dot_alert_dot_alert__requests__pb2.SetAlertConditionPresenceRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetAlertSignalPresence': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAlertSignalPresence,
                    request_deserializer=t2iapi_dot_alert_dot_alert__requests__pb2.SetAlertSignalPresenceRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetAudioPause': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAudioPause,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'CancelAudioPause': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelAudioPause,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'AlertConditionEscalation': grpc.unary_unary_rpc_method_handler(
                    servicer.AlertConditionEscalation,
                    request_deserializer=t2iapi_dot_alert_dot_alert__requests__pb2.AlertConditionEscalationRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetAlarmSignalInactivationState': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAlarmSignalInactivationState,
                    request_deserializer=t2iapi_dot_alert_dot_alert__requests__pb2.SetAlarmSignalInactivationStateRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetAlertSystemNotFunctional': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAlertSystemNotFunctional,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'InitiateAlarmOff': grpc.unary_unary_rpc_method_handler(
                    servicer.InitiateAlarmOff,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            't2iapi.alert.AlertService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AlertService(object):
    """
    Service to handle alert manipulations.
    """

    @staticmethod
    def SetAlertConditionPresence(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/SetAlertConditionPresence',
            t2iapi_dot_alert_dot_alert__requests__pb2.SetAlertConditionPresenceRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAlertSignalPresence(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/SetAlertSignalPresence',
            t2iapi_dot_alert_dot_alert__requests__pb2.SetAlertSignalPresenceRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAudioPause(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/SetAudioPause',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelAudioPause(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/CancelAudioPause',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AlertConditionEscalation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/AlertConditionEscalation',
            t2iapi_dot_alert_dot_alert__requests__pb2.AlertConditionEscalationRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAlarmSignalInactivationState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/SetAlarmSignalInactivationState',
            t2iapi_dot_alert_dot_alert__requests__pb2.SetAlarmSignalInactivationStateRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAlertSystemNotFunctional(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/SetAlertSystemNotFunctional',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitiateAlarmOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/InitiateAlarmOff',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/response_types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bt2iapi/response_types.proto\x12\x06t2iapi\x1a\x1egoogle/protobuf/wrappers.proto\"\xac\x01\n\x15PartialIdentification\x12*\n\x04root\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\textension\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x13identification_type\x18\x03 \x01(\x0b\x32\x19.t2iapi.PartialCodedValue\">\n\x11PartialCodedValue\x12)\n\x0ctranslations\x18\x01 \x03(\x0b\x32\x13.t2iapi.Translation\"{\n\x0bTranslation\x12\x18\n\x10translation_code\x18\x01 \x01(\t\x12\x15\n\rcoding_system\x18\x02 \x01(\t\x12;\n\x15\x63oding_system_version\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue*c\n\x06Result\x12\x0f\n\x0bRESULT_FAIL\x10\x00\x12\x12\n\x0eRESULT_SUCCESS\x10\x01\x12\x18\n\x14RESULT_NOT_SUPPORTED\x10\x02\x12\x1a\n\x16RESULT_NOT_IMPLEMENTED\x10\x03\x42+\n\x1a\x63om.draeger.medical.t2iapiB\rResponseTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.response_types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.draeger.medical.t2iapiB\rResponseTypes'
  _RESULT._serialized_start=435
  _RESULT._serialized_end=534
  _PARTIALIDENTIFICATION._serialized_start=72
  _PARTIALIDENTIFICATION._serialized_end=244
  _PARTIALCODEDVALUE._serialized_start=246
  _PARTIALCODEDVALUE._serialized_end=308
  _TRANSLATION._serialized_start=310
  _TRANSLATION._serialized_end=433
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi.context import context_requests_pb2 as t2iapi_dot_context_dot_context__requests__pb2
from t2iapi.context import context_responses_pb2 as t2iapi_dot_context_dot_context__responses__pb2


class ContextServiceStub(object):
    """
    Service to handle context manipulations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetLocationDetail = channel.unary_unary(
                '/t2iapi.context.ContextService/SetLocationDetail',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.SetLocationDetailRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.RemoveAllContextStateValidators = channel.unary_unary(
                '/t2iapi.context.ContextService/RemoveAllContextStateValidators',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetContextStateAssociation = channel.unary_unary(
                '/t2iapi.context.ContextService/SetContextStateAssociation',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.SetContextStateAssociationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.CreateContextStateWithAssociation = channel.unary_unary(
                '/t2iapi.context.ContextService/CreateContextStateWithAssociation',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
                )
        self.CreateContextStateWithAssociationAndValidators = channel.unary_unary(
                '/t2iapi.context.ContextService/CreateContextStateWithAssociationAndValidators',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationAndValidatorsRequest.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
                )
        self.CreateContextStateWithAssociationAndUniqueIdentification = channel.unary_unary(
                '/t2iapi.context.ContextService/CreateContextStateWithAssociationAndUniqueIdentification',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationAndUniqueIdentificationResponse.FromString,
                )
        self.CreateContextStateWithAssocIdentificationAndValidator = channel.unary_unary(
                '/t2iapi.context.ContextService/CreateContextStateWithAssocIdentificationAndValidator',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.RemoveIdentificationOfContextState = channel.unary_unary(
                '/t2iapi.context.ContextService/RemoveIdentificationOfContextState',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.ChangeIdentificationOfContextState = channel.unary_unary(
                '/t2iapi.context.ContextService/ChangeIdentificationOfContextState',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.CreateContextStateWithAssocAndSpecificValidator = channel.unary_unary(
                '/t2iapi.context.ContextService/CreateContextStateWithAssocAndSpecificValidator',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssocAndSpecificValidatorRequest.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
                )
        self.CreateNeonatalPatientWithAssociationAndMothersIdentification = channel.unary_unary(
                '/t2iapi.context.ContextService/CreateNeonatalPatientWithAssociationAndMothersIdentification',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
                )
        self.AssociatePatient = channel.unary_unary(
                '/t2iapi.context.ContextService/AssociatePatient',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.AssociatePatientRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.EnsembleContextIndicateMembership = channel.unary_unary(
                '/t2iapi.context.ContextService/EnsembleContextIndicateMembership',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.EnsembleContextIndicateMembershipWithIdentification = channel.unary_unary(
                '/t2iapi.context.ContextService/EnsembleContextIndicateMembershipWithIdentification',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.EnsembleContextIndicateMembershipWithIdentificationResponse.FromString,
                )
        self.GetSupportedContextTypes = channel.unary_unary(
                '/t2iapi.context.ContextService/GetSupportedContextTypes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.GetSupportedContextTypesResponse.FromString,
                )
        self.AssociatePatientWithAutoGeneratedPatientId = channel.unary_unary(
                '/t2iapi.context.ContextService/AssociatePatientWithAutoGeneratedPatientId',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
                )


class ContextServiceServicer(object):
    """
    Service to handle context manipulations.
    """

    def SetLocationDetail(self, request, context):
        """
        Use the given LocationDetail in a currently associated LocationContextState or associate a new LocationContextState
        with the LocationDetail.
        The goal of this rpc is to have an associated LocationContextState, that contains the given LocationDetail.
        This can for example be achieved by changing the location of the device in its settings UI.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveAllContextStateValidators(self, request, context):
        """
        Remove all Validators elements for the AbstractContextState with the provided context state handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetContextStateAssociation(self, request, context):
        """
        Set the ContextAssociation of the target ContextState to the given value.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateContextStateWithAssociation(self, request, context):
        """
        Create a new ContextState instance with the given ContextAssociation value for the given descriptor handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateContextStateWithAssociationAndValidators(self, request, context):
        """
        Create a new pm:AbstractContextState instance with the given @ContextAssociation value for the given descriptor handle
        and provide at least the number of pm:Validator elements for this ContextState.
        If the number of pm:Validator elements is zero, zero pm:Validator elements shall be provided.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateContextStateWithAssociationAndUniqueIdentification(self, request, context):
        """
        Create a new ContextState instance with the given ContextAssociation value for the given descriptor handle
        and provide the unique identification.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateContextStateWithAssocIdentificationAndValidator(self, request, context):
        """
        Create a new ContextState instance with the given ContextAssociation value for the given descriptor handle
        and provide at least one Identification and Validator for this ContextState.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveIdentificationOfContextState(self, request, context):
        """
        Remove at least one pm:Identification element for the pm:AbstractContextState/@Handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeIdentificationOfContextState(self, request, context):
        """
        Change at least one pm:Identification element for the pm:AbstractContextState/@Handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateContextStateWithAssocAndSpecificValidator(self, request, context):
        """
        Create a new ContextState instance with the given ContextAssociation value for the given descriptor handle,
        confirm by requested validator type.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNeonatalPatientWithAssociationAndMothersIdentification(self, request, context):
        """
        Create a new neonatal patient with a given type of association and
        including the mothers identification.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AssociatePatient(self, request, context):
        """
        Create or adapt a PatientContextState with CoreData/PatientType having the requested patient type.
        The PatientContextState/@ContextAssociation shall be "Associated".
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnsembleContextIndicateMembership(self, request, context):
        """
        Indicate membership in an SDC PARTICIPANT ENSEMBLE using an ensemble context, indicated by its descriptor handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnsembleContextIndicateMembershipWithIdentification(self, request, context):
        """
        Indicate membership in an SDC PARTICIPANT ENSEMBLE using an ensemble context that has the provided descriptor handle
        and return a list of pm:Identification elements which identify an ensemble and thus enable the caller to distinguish
        ensembles from each other.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSupportedContextTypes(self, request, context):
        """
        Returns all types of contexts which are supported by the DUT.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AssociatePatientWithAutoGeneratedPatientId(self, request, context):
        """
        Create or adapt a pm:PatientContextState having an associated patient with an auto generated patient id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ContextServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetLocationDetail': grpc.unary_unary_rpc_method_handler(
                    servicer.SetLocationDetail,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.SetLocationDetailRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'RemoveAllContextStateValidators': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveAllContextStateValidators,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetContextStateAssociation': grpc.unary_unary_rpc_method_handler(
                    servicer.SetContextStateAssociation,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.SetContextStateAssociationRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'CreateContextStateWithAssociation': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateContextStateWithAssociation,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.SerializeToString,
            ),
            'CreateContextStateWithAssociationAndValidators': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateContextStateWithAssociationAndValidators,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationAndValidatorsRequest.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.SerializeToString,
            ),
            'CreateContextStateWithAssociationAndUniqueIdentification': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateContextStateWithAssociationAndUniqueIdentification,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationAndUniqueIdentificationResponse.SerializeToString,
            ),
            'CreateContextStateWithAssocIdentificationAndValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateContextStateWithAssocIdentificationAndValidator,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'RemoveIdentificationOfContextState': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveIdentificationOfContextState,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'ChangeIdentificationOfContextState': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeIdentificationOfContextState,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'CreateContextStateWithAssocAndSpecificValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateContextStateWithAssocAndSpecificValidator,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssocAndSpecificValidatorRequest.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.SerializeToString,
            ),
            'CreateNeonatalPatientWithAssociationAndMothersIdentification': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNeonatalPatientWithAssociationAndMothersIdentification,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.SerializeToString,
            ),
            'AssociatePatient': grpc.unary_unary_rpc_method_handler(
                    servicer.AssociatePatient,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.AssociatePatientRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'EnsembleContextIndicateMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.EnsembleContextIndicateMembership,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'EnsembleContextIndicateMembershipWithIdentification': grpc.unary_unary_rpc_method_handler(
                    servicer.EnsembleContextIndicateMembershipWithIdentification,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.EnsembleContextIndicateMembershipWithIdentificationResponse.SerializeToString,
            ),
            'GetSupportedContextTypes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSupportedContextTypes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.GetSupportedContextTypesResponse.SerializeToString,
            ),
            'AssociatePatientWithAutoGeneratedPatientId': grpc.unary_unary_rpc_method_handler(
                    servicer.AssociatePatientWithAutoGeneratedPatientId,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            't2iapi.context.ContextService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ContextService(object):
    """
    Service to handle context manipulations.
    """

    @staticmethod
    def SetLocationDetail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/SetLocationDetail',
            t2iapi_dot_context_dot_context__requests__pb2.SetLocationDetailRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveAllContextStateValidators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/RemoveAllContextStateValidators',
            t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetContextStateAssociation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/SetContextStateAssociation',
            t2iapi_dot_context_dot_context__requests__pb2.SetContextStateAssociationRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateContextStateWithAssociation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/CreateContextStateWithAssociation',
            t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateContextStateWithAssociationAndValidators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/CreateContextStateWithAssociationAndValidators',
            t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationAndValidatorsRequest.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateContextStateWithAssociationAndUniqueIdentification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/CreateContextStateWithAssociationAndUniqueIdentification',
            t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationAndUniqueIdentificationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateContextStateWithAssocIdentificationAndValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/CreateContextStateWithAssocIdentificationAndValidator',
            t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveIdentificationOfContextState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/RemoveIdentificationOfContextState',
            t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeIdentificationOfContextState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/ChangeIdentificationOfContextState',
            t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateContextStateWithAssocAndSpecificValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/CreateContextStateWithAssocAndSpecificValidator',
            t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssocAndSpecificValidatorRequest.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNeonatalPatientWithAssociationAndMothersIdentification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/CreateNeonatalPatientWithAssociationAndMothersIdentification',
            t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AssociatePatient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/AssociatePatient',
            t2iapi_dot_context_dot_context__requests__pb2.AssociatePatientRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnsembleContextIndicateMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/EnsembleContextIndicateMembership',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnsembleContextIndicateMembershipWithIdentification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/EnsembleContextIndicateMembershipWithIdentification',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.EnsembleContextIndicateMembershipWithIdentificationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSupportedContextTypes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/GetSupportedContextTypes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.GetSupportedContextTypesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AssociatePatientWithAutoGeneratedPatientId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/AssociatePatientWithAutoGeneratedPatientId',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/device/device_responses.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$t2iapi/device/device_responses.proto\x12\rt2iapi.device\x1a\x1ct2iapi/basic_responses.proto\"X\n\x1fGetRemovableDescriptorsResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x0e\n\x06handle\x18\x02 \x03(\t\"T\n\x1bInsertMdsDescriptorResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x0e\n\x06handle\x18\x02 \x01(\tB4\n!com.draeger.medical.t2iapi.deviceB\x0f\x44\x65viceResponsesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.device.device_responses_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.deviceB\017DeviceResponses'
  _GETREMOVABLEDESCRIPTORSRESPONSE._serialized_start=85
  _GETREMOVABLEDESCRIPTORSRESPONSE._serialized_end=173
  _INSERTMDSDESCRIPTORRESPONSE._serialized_start=175
  _INSERTMDSDESCRIPTORRESPONSE._serialized_end=259
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/context/context_responses.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi import response_types_pb2 as t2iapi_dot_response__types__pb2
from t2iapi.context import types_pb2 as t2iapi_dot_context_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&t2iapi/context/context_responses.proto\x12\x0et2iapi.context\x1a\x1ct2iapi/basic_responses.proto\x1a\x1bt2iapi/response_types.proto\x1a\x1at2iapi/context/types.proto\"p\n)CreateContextStateWithAssociationResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x1c\n\x14\x63ontext_state_handle\x18\x02 \x01(\t\"\xa8\x01\n@CreateContextStateWithAssociationAndUniqueIdentificationResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x1c\n\x14\x63ontext_state_handle\x18\x02 \x01(\t\x12\x11\n\textension\x18\x03 \x01(\t\x12\x0c\n\x04root\x18\x04 \x01(\t\"|\n GetSupportedContextTypesResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x31\n\x0c\x63ontext_type\x18\x02 \x03(\x0e\x32\x1b.t2iapi.context.ContextType\"\x9b\x01\n;EnsembleContextIndicateMembershipWithIdentificationResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x35\n\x0eidentification\x18\x02 \x03(\x0b\x32\x1d.t2iapi.PartialIdentificationB6\n\"com.draeger.medical.t2iapi.contextB\x10\x43ontextResponsesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.context.context_responses_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.draeger.medical.t2iapi.contextB\020ContextResponses'
  _CREATECONTEXTSTATEWITHASSOCIATIONRESPONSE._serialized_start=145
  _CREATECONTEXTSTATEWITHASSOCIATIONRESPONSE._serialized_end=257
  _CREATECONTEXTSTATEWITHASSOCIATIONANDUNIQUEIDENTIFICATIONRESPONSE._serialized_start=260
  _CREATECONTEXTSTATEWITHASSOCIATIONANDUNIQUEIDENTIFICATIONRESPONSE._serialized_end=428
  _GETSUPPORTEDCONTEXTTYPESRESPONSE._serialized_start=430
  _GETSUPPORTEDCONTEXTTYPESRESPONSE._serialized_end=554
  _ENSEMBLECONTEXTINDICATEMEMBERSHIPWITHIDENTIFICATIONRESPONSE._serialized_start=557
  _ENSEMBLECONTEXTINDICATEMEMBERSHIPWITHIDENTIFICATIONRESPONSE._serialized_end=712
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/device/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19t2iapi/device/types.proto\x12\rt2iapi.device\x1a\x1egoogle/protobuf/wrappers.proto\"M\n\x0c\x45xpandedName\x12)\n\x03uri\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x12\n\nlocal_name\x18\x02 \x01(\t*\x80\x05\n\nReportType\x12%\n!REPORT_TYPE_EPISODIC_ALERT_REPORT\x10\x00\x12)\n%REPORT_TYPE_EPISODIC_COMPONENT_REPORT\x10\x01\x12\'\n#REPORT_TYPE_EPISODIC_CONTEXT_REPORT\x10\x02\x12&\n\"REPORT_TYPE_EPISODIC_METRIC_REPORT\x10\x03\x12\x31\n-REPORT_TYPE_EPISODIC_OPERATIONAL_STATE_REPORT\x10\x04\x12%\n!REPORT_TYPE_PERIODIC_ALERT_REPORT\x10\x05\x12)\n%REPORT_TYPE_PERIODIC_COMPONENT_REPORT\x10\x06\x12\'\n#REPORT_TYPE_PERIODIC_CONTEXT_REPORT\x10\x07\x12&\n\"REPORT_TYPE_PERIODIC_METRIC_REPORT\x10\x08\x12\x31\n-REPORT_TYPE_PERIODIC_OPERATIONAL_STATE_REPORT\x10\t\x12/\n+REPORT_TYPE_DESCRIPTION_MODIFICATION_REPORT\x10\n\x12(\n$REPORT_TYPE_OPERATION_INVOKED_REPORT\x10\x0b\x12#\n\x1fREPORT_TYPE_SYSTEM_ERROR_REPORT\x10\x0c\x12%\n!REPORT_TYPE_OBSERVED_VALUE_STREAM\x10\r\x12\x1f\n\x1bREPORT_TYPE_WAVEFORM_STREAM\x10\x0e*\x92\x01\n\x10MdsOperatingMode\x12\x1d\n\x19MDS_OPERATING_MODE_NORMAL\x10\x00\x12\x1b\n\x17MDS_OPERATING_MODE_DEMO\x10\x01\x12\x1e\n\x1aMDS_OPERATING_MODE_SERVICE\x10\x02\x12\"\n\x1eMDS_OPERATING_MODE_MAINTENANCE\x10\x03*J\n\x0f\x44\x65scriptorClass\x12\x1d\n\x19\x44\x45SCRIPTOR_CLASS_ABSTRACT\x10\x00\x12\x18\n\x14\x44\x45SCRIPTOR_CLASS_MDS\x10\x01\x42\x30\n!com.draeger.medical.t2iapi.deviceB\x0b\x44\x65viceTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.device.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.deviceB\013DeviceTypes'
  _REPORTTYPE._serialized_start=156
  _REPORTTYPE._serialized_end=796
  _MDSOPERATINGMODE._serialized_start=799
  _MDSOPERATINGMODE._serialized_end=945
  _DESCRIPTORCLASS._serialized_start=947
  _DESCRIPTORCLASS._serialized_end=1021
  _EXPANDEDNAME._serialized_start=76
  _EXPANDEDNAME._serialized_end=153
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi.operation import operation_requests_pb2 as t2iapi_dot_operation_dot_operation__requests__pb2


class OperationServiceStub(object):
    """
    Service to handle operation manipulations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetOperatingMode = channel.unary_unary(
                '/t2iapi.operation.OperationService/SetOperatingMode',
                request_serializer=t2iapi_dot_operation_dot_operation__requests__pb2.SetOperatingModeRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )


class OperationServiceServicer(object):
    """
    Service to handle operation manipulations.
    """

    def SetOperatingMode(self, request, context):
        """
        This manipulation shall change the devices state, which results in setting the requested OperatingMode for the
        given operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OperationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetOperatingMode': grpc.unary_unary_rpc_method_handler(
                    servicer.SetOperatingMode,
                    request_deserializer=t2iapi_dot_operation_dot_operation__requests__pb2.SetOperatingModeRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            't2iapi.operation.OperationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OperationService(object):
    """
    Service to handle operation manipulations.
    """

    @staticmethod
    def SetOperatingMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.operation.OperationService/SetOperatingMode',
            t2iapi_dot_operation_dot_operation__requests__pb2.SetOperatingModeRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/context/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1at2iapi/context/types.proto\x12\x0et2iapi.context\x1a\x1egoogle/protobuf/wrappers.proto\"\x9f\x02\n\x0eLocationDetail\x12)\n\x03poc\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04room\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x03\x62\x65\x64\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x66\x61\x63ility\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x62uilding\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x66loor\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue*\xaf\x01\n\x12\x43ontextAssociation\x12&\n\"CONTEXT_ASSOCIATION_NOT_ASSOCIATED\x10\x00\x12&\n\"CONTEXT_ASSOCIATION_PRE_ASSOCIATED\x10\x01\x12\"\n\x1e\x43ONTEXT_ASSOCIATION_ASSOCIATED\x10\x02\x12%\n!CONTEXT_ASSOCIATION_DISASSOCIATED\x10\x03*\xc8\x01\n\x0bPatientType\x12\x1c\n\x18PATIENT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12PATIENT_TYPE_ADULT\x10\x01\x12\x1b\n\x17PATIENT_TYPE_ADOLESCENT\x10\x02\x12\x1a\n\x16PATIENT_TYPE_PEDIATRIC\x10\x03\x12\x17\n\x13PATIENT_TYPE_INFANT\x10\x04\x12\x19\n\x15PATIENT_TYPE_NEONATAL\x10\x05\x12\x16\n\x12PATIENT_TYPE_OTHER\x10\x06*\xe2\x01\n\rValidatorType\x12\x17\n\x13VALIDATOR_TYPE_USER\x10\x00\x12&\n\"VALIDATOR_TYPE_CLINICAL_SUPER_USER\x10\x01\x12\x19\n\x15VALIDATOR_TYPE_BIOMED\x10\x02\x12$\n VALIDATOR_TYPE_SERVICE_PERSONNEL\x10\x03\x12+\n\'VALIDATOR_TYPE_REMOTE_SERVICE_OPERATION\x10\x04\x12\"\n\x1eVALIDATOR_TYPE_TECHNICAL_MEANS\x10\x05*\xab\x01\n\x0b\x43ontextType\x12\x18\n\x14\x43ONTEXT_TYPE_PATIENT\x10\x00\x12\x19\n\x15\x43ONTEXT_TYPE_LOCATION\x10\x01\x12\x19\n\x15\x43ONTEXT_TYPE_WORKFLOW\x10\x02\x12\x19\n\x15\x43ONTEXT_TYPE_OPERATOR\x10\x03\x12\x16\n\x12\x43ONTEXT_TYPE_MEANS\x10\x04\x12\x19\n\x15\x43ONTEXT_TYPE_ENSEMBLE\x10\x05\x42\x32\n\"com.draeger.medical.t2iapi.contextB\x0c\x43ontextTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.context.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.draeger.medical.t2iapi.contextB\014ContextTypes'
  _CONTEXTASSOCIATION._serialized_start=369
  _CONTEXTASSOCIATION._serialized_end=544
  _PATIENTTYPE._serialized_start=547
  _PATIENTTYPE._serialized_end=747
  _VALIDATORTYPE._serialized_start=750
  _VALIDATORTYPE._serialized_end=976
  _CONTEXTTYPE._serialized_start=979
  _CONTEXTTYPE._serialized_end=1150
  _LOCATIONDETAIL._serialized_start=79
  _LOCATIONDETAIL._serialized_end=366
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/metric/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19t2iapi/metric/types.proto\x12\rt2iapi.metric*\xe7\x02\n\x13MeasurementValidity\x12\x1e\n\x1aMEASUREMENT_VALIDITY_VALID\x10\x00\x12\'\n#MEASUREMENT_VALIDITY_VALIDATED_DATA\x10\x01\x12,\n(MEASUREMENT_VALIDITY_MEASUREMENT_ONGOING\x10\x02\x12%\n!MEASUREMENT_VALIDITY_QUESTIONABLE\x10\x03\x12,\n(MEASUREMENT_VALIDITY_CALIBRATION_ONGOING\x10\x04\x12 \n\x1cMEASUREMENT_VALIDITY_INVALID\x10\x05\x12!\n\x1dMEASUREMENT_VALIDITY_OVERFLOW\x10\x06\x12\"\n\x1eMEASUREMENT_VALIDITY_UNDERFLOW\x10\x07\x12\x1b\n\x17MEASUREMENT_VALIDITY_NA\x10\x08*^\n\x0eGenerationMode\x12\x18\n\x14GENERATION_MODE_REAL\x10\x00\x12\x18\n\x14GENERATION_MODE_TEST\x10\x01\x12\x18\n\x14GENERATION_MODE_DEMO\x10\x02*t\n\x13OperationModeStatus\x12\x1c\n\x18OPERATION_MODE_STATUS_ON\x10\x00\x12\x1d\n\x19OPERATION_MODE_STATUS_OFF\x10\x01\x12 \n\x1cOPERATION_MODE_STATUS_PAUSED\x10\x02*\xa6\x02\n\x0cMetricStatus\x12&\n\"METRIC_STATUS_PERFORMED_OR_APPLIED\x10\x00\x12(\n$METRIC_STATUS_CURRENTLY_INITIALIZING\x10\x01\x12<\n8METRIC_STATUS_INITIALIZED_BUT_NOT_PERFORMING_OR_APPLYING\x10\x02\x12+\n\'METRIC_STATUS_CURRENTLY_DE_INITIALIZING\x10\x03\x12?\n;METRIC_STATUS_DE_INITIALIZED_AND_NOT_PERFORMING_OR_APPLYING\x10\x04\x12\x18\n\x14METRIC_STATUS_FAILED\x10\x05\x42\x30\n!com.draeger.medical.t2iapi.metricB\x0bMetricTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.metric.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.metricB\013MetricTypes'
  _MEASUREMENTVALIDITY._serialized_start=45
  _MEASUREMENTVALIDITY._serialized_end=404
  _GENERATIONMODE._serialized_start=406
  _GENERATIONMODE._serialized_end=500
  _OPERATIONMODESTATUS._serialized_start=502
  _OPERATIONMODESTATUS._serialized_end=618
  _METRICSTATUS._serialized_start=621
  _METRICSTATUS._serialized_end=915
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/activation_state/activation_state_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.activation_state import types_pb2 as t2iapi_dot_activation__state_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7t2iapi/activation_state/activation_state_requests.proto\x12\x17t2iapi.activation_state\x1a#t2iapi/activation_state/types.proto\"q\n\x1dSetComponentActivationRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12@\n\nactivation\x18\x02 \x01(\x0e\x32,.t2iapi.activation_state.ComponentActivation\"i\n\x19SetAlertActivationRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12<\n\nactivation\x18\x02 \x01(\x0e\x32(.t2iapi.activation_state.AlertActivation\"\xba\x01\n SetSystemSignalActivationRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12H\n\rmanifestation\x18\x02 \x01(\x0e\x32\x31.t2iapi.activation_state.AlertSignalManifestation\x12<\n\nactivation\x18\x03 \x01(\x0e\x32(.t2iapi.activation_state.AlertActivationBF\n+com.draeger.medical.t2iapi.activation_stateB\x17\x41\x63tivationStateRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.activation_state.activation_state_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.draeger.medical.t2iapi.activation_stateB\027ActivationStateRequests'
  _SETCOMPONENTACTIVATIONREQUEST._serialized_start=121
  _SETCOMPONENTACTIVATIONREQUEST._serialized_end=234
  _SETALERTACTIVATIONREQUEST._serialized_start=236
  _SETALERTACTIVATIONREQUEST._serialized_end=341
  _SETSYSTEMSIGNALACTIVATIONREQUEST._serialized_start=344
  _SETSYSTEMSIGNALACTIVATIONREQUEST._serialized_end=530
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/device/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi.device import device_requests_pb2 as t2iapi_dot_device_dot_device__requests__pb2
from t2iapi.device import device_responses_pb2 as t2iapi_dot_device_dot_device__responses__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bt2iapi/device/service.proto\x12\rt2iapi.device\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1ct2iapi/basic_responses.proto\x1a\x1bt2iapi/basic_requests.proto\x1a#t2iapi/device/device_requests.proto\x1a$t2iapi/device/device_responses.proto2\xe6\x08\n\rDeviceService\x12]\n\x16SetDeviceOperatingMode\x12,.t2iapi.device.SetDeviceOperatingModeRequest\x1a\x15.t2iapi.BasicResponse\x12?\n\x0eShutDownDevice\x12\x16.google.protobuf.Empty\x1a\x15.t2iapi.BasicResponse\x12=\n\x0c\x42ootUpDevice\x12\x16.google.protobuf.Empty\x1a\x15.t2iapi.BasicResponse\x12:\n\tSendHello\x12\x16.google.protobuf.Empty\x1a\x15.t2iapi.BasicResponse\x12?\n\x0eSetClockDevice\x12\x16.google.protobuf.Empty\x1a\x15.t2iapi.BasicResponse\x12G\n\x0bSetLanguage\x12!.t2iapi.device.SetLanguageRequest\x1a\x15.t2iapi.BasicResponse\x12\x86\x01\n\x1eGetRemovableDescriptorsOfClass\x12\x34.t2iapi.device.GetRemovableDescriptorsOfClassRequest\x1a..t2iapi.device.GetRemovableDescriptorsResponse\x12\x45\n\x10RemoveDescriptor\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x45\n\x10InsertDescriptor\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12Y\n\x14\x43hangeMdibSequenceID\x12*.t2iapi.device.ChangeMdibSequenceIdRequest\x1a\x15.t2iapi.BasicResponse\x12Y\n\x13InsertMdsDescriptor\x12\x16.google.protobuf.Empty\x1a*.t2iapi.device.InsertMdsDescriptorResponse\x12H\n\x13RemoveMdsDescriptor\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12L\n\x17TriggerDescriptorUpdate\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12K\n\rTriggerReport\x12#.t2iapi.device.TriggerReportRequest\x1a\x15.t2iapi.BasicResponseB5\n!com.draeger.medical.t2iapi.deviceB\x10\x44\x65viceApiServiceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.device.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.deviceB\020DeviceApiService'
  _DEVICESERVICE._serialized_start=210
  _DEVICESERVICE._serialized_end=1336
# @@protoc_insertion_point(module_scope)
